==> openshift-serverless-logic-1.26.0-src.zip: openshift-serverless-logic-1.26.0.GA-src/org.kie.kogito-kogito-apps-1.30.0.Final/ui-packages/packages/custom-dashboard-view/src/envelope/CustomDashboardViewEnvelopeView.tsx <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useImperativeHandle, useState } from 'react';
import { MessageBusClientApi } from '@kogito-tooling/envelope-bus/dist/api';
import { CustomDashboardViewChannelApi } from '../api';
import CustomDashboardView from './components/CustomDashboardView/CustomDashboardView';
import CustomDashboardViewEnvelopeViewDriver from './CustomDashboardViewEnvelopeViewDriver';
import '@patternfly/patternfly/patternfly.css';

export interface CustomDashboardViewEnvelopeViewApi {
  initialize: (dashboardName: string) => void;
}

interface Props {
  channelApi: MessageBusClientApi<CustomDashboardViewChannelApi>;
}

export const CustomDashboardViewEnvelopeView = React.forwardRef<
  CustomDashboardViewEnvelopeViewApi,
  Props
>((props, forwardedRef) => {
  const [
    isEnvelopeConnectedToChannel,
    setEnvelopeConnectedToChannel
  ] = useState<boolean>(false);

  const [customDashboardName, setCustomDashboardName] = useState<string>();

  useImperativeHandle(
    forwardedRef,
    () => ({
      initialize: (dashboardName: string) => {
        setEnvelopeConnectedToChannel(true);
        setCustomDashboardName(dashboardName);
      }
    }),
    []
  );
  return (
    <>
      {customDashboardName && customDashboardName != 'undefined' && (
        <CustomDashboardView
          isEnvelopeConnectedToChannel={isEnvelopeConnectedToChannel}
          driver={new CustomDashboardViewEnvelopeViewDriver(props.channelApi)}
          customDashboardName={customDashboardName}
        />
      )}
    </>
  );
});

export default CustomDashboardViewEnvelopeView;

==> openshift-serverless-logic-1.29.0-src.zip: openshift-serverless-logic-1.29.0.GA-src/org.kie.kogito-kogito-apps-1.38.0.Final/ui-packages/packages/custom-dashboard-view/src/envelope/CustomDashboardViewEnvelopeView.tsx <==
/*
 * Copyright 2022 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { useImperativeHandle, useState } from 'react';
import { MessageBusClientApi } from '@kogito-tooling/envelope-bus/dist/api';
import { CustomDashboardViewChannelApi } from '../api';
import CustomDashboardView from './components/CustomDashboardView/CustomDashboardView';
import CustomDashboardViewEnvelopeViewDriver from './CustomDashboardViewEnvelopeViewDriver';
import '@patternfly/patternfly/patternfly.css';

export interface CustomDashboardViewEnvelopeViewApi {
  initialize: (dashboardName: string) => void;
}

interface Props {
  channelApi: MessageBusClientApi<CustomDashboardViewChannelApi>;
}

export const CustomDashboardViewEnvelopeView = React.forwardRef<
  CustomDashboardViewEnvelopeViewApi,
  Props
>((props, forwardedRef) => {
  const [isEnvelopeConnectedToChannel, setEnvelopeConnectedToChannel] =
    useState<boolean>(false);

  const [customDashboardName, setCustomDashboardName] = useState<string>();

  useImperativeHandle(
    forwardedRef,
    () => ({
      initialize: (dashboardName: string) => {
        setEnvelopeConnectedToChannel(true);
        setCustomDashboardName(dashboardName);
      }
    }),
    []
  );
  return (
    <>
      {customDashboardName && customDashboardName != 'undefined' && (
        <CustomDashboardView
          isEnvelopeConnectedToChannel={isEnvelopeConnectedToChannel}
          driver={new CustomDashboardViewEnvelopeViewDriver(props.channelApi)}
          customDashboardName={customDashboardName}
        />
      )}
    </>
  );
});

export default CustomDashboardViewEnvelopeView;
